"""File generated by TLObjects' generator. All changes will be ERASED"""
from ...tl.tlobject import TLObject


class FileGif(TLObject):
    constructor_id = 0xcae1aadf
    subclass_of_id = 0xf3a1e6f3

    def __init__(self):
        super().__init__()

    @staticmethod
    def to_dict():
        return {}

    def on_send(self, writer):
        writer.write_int(FileGif.constructor_id, signed=False)

    @staticmethod
    def empty():
        return FileGif()

    def on_response(self, reader):
        pass

    def __repr__(self):
        return 'storage.fileGif#cae1aadf = storage.FileType'

    def __str__(self):
        return TLObject.pretty_format(self)

    def stringify(self):
        return TLObject.pretty_format(self, indent=0)



class FileJpeg(TLObject):
    constructor_id = 0x7efe0e
    subclass_of_id = 0xf3a1e6f3

    def __init__(self):
        super().__init__()

    @staticmethod
    def to_dict():
        return {}

    def on_send(self, writer):
        writer.write_int(FileJpeg.constructor_id, signed=False)

    @staticmethod
    def empty():
        return FileJpeg()

    def on_response(self, reader):
        pass

    def __repr__(self):
        return 'storage.fileJpeg#007efe0e = storage.FileType'

    def __str__(self):
        return TLObject.pretty_format(self)

    def stringify(self):
        return TLObject.pretty_format(self, indent=0)



class FileMov(TLObject):
    constructor_id = 0x4b09ebbc
    subclass_of_id = 0xf3a1e6f3

    def __init__(self):
        super().__init__()

    @staticmethod
    def to_dict():
        return {}

    def on_send(self, writer):
        writer.write_int(FileMov.constructor_id, signed=False)

    @staticmethod
    def empty():
        return FileMov()

    def on_response(self, reader):
        pass

    def __repr__(self):
        return 'storage.fileMov#4b09ebbc = storage.FileType'

    def __str__(self):
        return TLObject.pretty_format(self)

    def stringify(self):
        return TLObject.pretty_format(self, indent=0)



class FileMp3(TLObject):
    constructor_id = 0x528a0677
    subclass_of_id = 0xf3a1e6f3

    def __init__(self):
        super().__init__()

    @staticmethod
    def to_dict():
        return {}

    def on_send(self, writer):
        writer.write_int(FileMp3.constructor_id, signed=False)

    @staticmethod
    def empty():
        return FileMp3()

    def on_response(self, reader):
        pass

    def __repr__(self):
        return 'storage.fileMp3#528a0677 = storage.FileType'

    def __str__(self):
        return TLObject.pretty_format(self)

    def stringify(self):
        return TLObject.pretty_format(self, indent=0)



class FileMp4(TLObject):
    constructor_id = 0xb3cea0e4
    subclass_of_id = 0xf3a1e6f3

    def __init__(self):
        super().__init__()

    @staticmethod
    def to_dict():
        return {}

    def on_send(self, writer):
        writer.write_int(FileMp4.constructor_id, signed=False)

    @staticmethod
    def empty():
        return FileMp4()

    def on_response(self, reader):
        pass

    def __repr__(self):
        return 'storage.fileMp4#b3cea0e4 = storage.FileType'

    def __str__(self):
        return TLObject.pretty_format(self)

    def stringify(self):
        return TLObject.pretty_format(self, indent=0)



class FilePartial(TLObject):
    constructor_id = 0x40bc6f52
    subclass_of_id = 0xf3a1e6f3

    def __init__(self):
        super().__init__()

    @staticmethod
    def to_dict():
        return {}

    def on_send(self, writer):
        writer.write_int(FilePartial.constructor_id, signed=False)

    @staticmethod
    def empty():
        return FilePartial()

    def on_response(self, reader):
        pass

    def __repr__(self):
        return 'storage.filePartial#40bc6f52 = storage.FileType'

    def __str__(self):
        return TLObject.pretty_format(self)

    def stringify(self):
        return TLObject.pretty_format(self, indent=0)



class FilePdf(TLObject):
    constructor_id = 0xae1e508d
    subclass_of_id = 0xf3a1e6f3

    def __init__(self):
        super().__init__()

    @staticmethod
    def to_dict():
        return {}

    def on_send(self, writer):
        writer.write_int(FilePdf.constructor_id, signed=False)

    @staticmethod
    def empty():
        return FilePdf()

    def on_response(self, reader):
        pass

    def __repr__(self):
        return 'storage.filePdf#ae1e508d = storage.FileType'

    def __str__(self):
        return TLObject.pretty_format(self)

    def stringify(self):
        return TLObject.pretty_format(self, indent=0)



class FilePng(TLObject):
    constructor_id = 0xa4f63c0
    subclass_of_id = 0xf3a1e6f3

    def __init__(self):
        super().__init__()

    @staticmethod
    def to_dict():
        return {}

    def on_send(self, writer):
        writer.write_int(FilePng.constructor_id, signed=False)

    @staticmethod
    def empty():
        return FilePng()

    def on_response(self, reader):
        pass

    def __repr__(self):
        return 'storage.filePng#0a4f63c0 = storage.FileType'

    def __str__(self):
        return TLObject.pretty_format(self)

    def stringify(self):
        return TLObject.pretty_format(self, indent=0)



class FileUnknown(TLObject):
    constructor_id = 0xaa963b05
    subclass_of_id = 0xf3a1e6f3

    def __init__(self):
        super().__init__()

    @staticmethod
    def to_dict():
        return {}

    def on_send(self, writer):
        writer.write_int(FileUnknown.constructor_id, signed=False)

    @staticmethod
    def empty():
        return FileUnknown()

    def on_response(self, reader):
        pass

    def __repr__(self):
        return 'storage.fileUnknown#aa963b05 = storage.FileType'

    def __str__(self):
        return TLObject.pretty_format(self)

    def stringify(self):
        return TLObject.pretty_format(self, indent=0)



class FileWebp(TLObject):
    constructor_id = 0x1081464c
    subclass_of_id = 0xf3a1e6f3

    def __init__(self):
        super().__init__()

    @staticmethod
    def to_dict():
        return {}

    def on_send(self, writer):
        writer.write_int(FileWebp.constructor_id, signed=False)

    @staticmethod
    def empty():
        return FileWebp()

    def on_response(self, reader):
        pass

    def __repr__(self):
        return 'storage.fileWebp#1081464c = storage.FileType'

    def __str__(self):
        return TLObject.pretty_format(self)

    def stringify(self):
        return TLObject.pretty_format(self, indent=0)

